Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
// Separator is used to separate nested errors.
Separator = ":\n\t"
)
Functions ¶
Types ¶
type Error ¶
type Error struct {
// Op is the performed operation, usually it is the method name.
// e.g. Bus.Publish()
Op Operation
// Kind of the error such as subscriber not found
// or "Other" if its class is unknown or irrelevant.
Kind Kind
// Err is the underlying error that has triggered this one, if any.
Err error
}
Error is the implementation of the error interface.
Click to show internal directories.
Click to hide internal directories.